/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Tomer Gidron
 *
 */

#include "FlagsAndLivesHUD.h"
#include "HoverFlag.h"
#include "Hover.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"
#include "util/Convert.h"

namespace orxonox
{
    RegisterClass(FlagsAndLivesHUD);

    FlagsAndLivesHUD::FlagsAndLivesHUD(Context* context) : OverlayText(context)
    {
        RegisterObject(FlagsAndLivesHUD);

        this->hoverGame_ = nullptr;
        this->totFlags_ = 0;
        showLives_ = false;
    }

    void FlagsAndLivesHUD::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(FlagsAndLivesHUD, XMLPort, xmlelement, mode);

        XMLPortParam(FlagsAndLivesHUD,"showPoints", setShowTot, getShowTot, xmlelement, mode);
        XMLPortParam(FlagsAndLivesHUD, "showLives", setShowLives, getShowLives, xmlelement, mode);
    }

    void FlagsAndLivesHUD::tick(float dt)
    {
        SUPER(FlagsAndLivesHUD, tick, dt);

            const std::string& flags = multi_cast<std::string>(this->hoverGame_->getTotFlags());
            const std::string& lives = multi_cast<std::string>(this->hoverGame_->getLives());

            if(showLives_ == false){
                setTextSize(0.04);
                setPosition(Vector2(0.18, 0.08));
                this->setColour(ColourValue(1, 1, 1, 1));
                this->setCaption(flags);
            }

            else{
                setTextSize(0.04);
                setPosition(Vector2(0.18, 0.12));
                this->setColour(ColourValue(1, 1, 1, 1));
                this->setCaption(lives);
            }
            
    }

    void FlagsAndLivesHUD::changedOwner()
    {
        SUPER(FlagsAndLivesHUD, changedOwner);

        if (this->getOwner() && this->getOwner()->getGametype())
        {
            this->hoverGame_ = orxonox_cast<Hover*>(this->getOwner()->getGametype());
        }
        else
        {
            this->hoverGame_ = nullptr;
        }
    }
}
